@@ -6,7 +6,7 @@ from subprocess import run, PIPE
 
 sys.path.append(f'{os.getenv("HOME")}/.config/pycher/')
 root_path = os.path.dirname(os.path.realpath(__file__))
-scripts = root_path + "/../scripts"
+scripts = root_path + "/scripts"
 
 from config import commands
 
